package com.example.smartlab

import android.content.ContentValues
import android.content.Intent
import androidx.appcompat.app.AppCompatActivity
import android.os.Bundle
import android.text.Editable
import android.text.TextWatcher
import android.util.Log
import android.util.Patterns
import android.widget.Button
import android.widget.EditText
import com.example.smartlab.Api.request
import com.google.gson.GsonBuilder
import kotlinx.coroutines.CoroutineScope
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.launch
import okhttp3.OkHttpClient
import okhttp3.logging.HttpLoggingInterceptor
import retrofit2.Retrofit
import retrofit2.converter.gson.GsonConverterFactory
import retrofit2.converter.scalars.ScalarsConverterFactory
import retrofit2.awaitResponse
import com.example.smartlab.databinding.ActivityWelcomeScreenBinding


class welcome_screen_activity : AppCompatActivity() {

    lateinit var inputtext :EditText
    lateinit var action_button :Button
    lateinit var binding: ActivityWelcomeScreenBinding

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_welcome_screen)

        binding = ActivityWelcomeScreenBinding.inflate(layoutInflater)

        inputtext=findViewById(R.id.emailText)
        action_button=findViewById(R.id.nextButton)

        inputtext.addTextChangedListener(object : TextWatcher
        {
            override fun beforeTextChanged(s: CharSequence?, start: Int, count: Int, after: Int) {

            }

            override fun onTextChanged(s: CharSequence?, start: Int, before: Int, count: Int) {
                if (s.isValidEmail())
            {
                action_button.isEnabled = true
                action_button.setBackgroundResource(R.drawable.blue_button_style)
            }
            }

            override fun afterTextChanged(s: Editable?) {

            }

        })

        listener()
    }

    fun CharSequence?.isValidEmail():Boolean{
        return !isNullOrEmpty() && Patterns
            .EMAIL_ADDRESS.matcher(this).matches()
    }

    private fun listener() {
        action_button.setOnClickListener()
        {
            SendEmail()
        }
    }

    fun SendEmail() {
        //interceptor - Перехватчик OkHttp, который регистрирует данные HTTP-запроса и ответа.
        //Создаем объект перехватчика
        val interceptor = HttpLoggingInterceptor()
        interceptor.level = HttpLoggingInterceptor.Level.BODY

        //Добавляем перехватчика в клиента
        val httpClient = OkHttpClient.Builder()
            .addInterceptor(interceptor)
            .build()


        val gsonBuilder = GsonBuilder()
            .setLenient()
            .create()

        val retrofit = Retrofit.Builder()
            .addConverterFactory(ScalarsConverterFactory.create())//Конвертер строк, обоих примитивов и их коробочных типов в text/plain тела.
            .addConverterFactory(GsonConverterFactory.create(gsonBuilder))
            .baseUrl("https://iis.ngknn.ru/NGKNN/МамшеваЮС/MedicMadlab/")
            .client(httpClient) //добавление http клиента в retrofit
            .build()
        val requestApi = retrofit.create(request::class.java)
        CoroutineScope(Dispatchers.IO).launch {
            try {
                requestApi.postEmail(inputtext.text.toString())
                    .awaitResponse() //Запуск метода из ApiRequest с переданым параметром в Header (заголовок)
                Log.d("Response", "Success send Email") // Вывод информации на консоль
                nextPage()
            } catch (e: Exception) {
                Log.d(ContentValues.TAG, e.toString()) // Вывод информации на консоль
            }
        }
    }

    private fun nextPage(){
        val intent = Intent(this, verification_from_email_activity::class.java)
        startActivity(intent)
    }
}